﻿using System;
using System.Collections;
using System.Collections.Generic;

using DevExpress.XtraEditors;
using DevExpress.XtraTreeList;
using DevExpress.XtraTreeList.Nodes;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Load += Form_Load;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.treeList.RowHeight                              = 25;
            this.treeList.OptionsView.AutoWidth                  = false;
            this.treeList.OptionsBehavior.ReadOnly               = true;
            this.treeList.OptionsBehavior.PopulateServiceColumns = true;
            this.treeList.OptionsSelection.MultiSelect           = true;
            this.treeList.OptionsSelection.MultiSelectMode       = TreeListMultiSelectMode.RowSelect;
            this.treeList.KeyFieldName                           = "ID";
            this.treeList.ParentFieldName                        = "RegionID";

            this.treeList.DataSource = SalesData.GetSalesDataList();

            this.treeList.Columns[this.treeList.KeyFieldName   ].Visible = false;
            this.treeList.Columns[this.treeList.ParentFieldName].Visible = false;

            this.treeList.BestFitColumns();

            this.treeList.ExpandAll();

            TreeListNode node = this.treeList.FindNodeByFieldValue("Region", "North America");

            if(node != null)
            {
                List<TreeListNode> nodeList = new List<TreeListNode>();

                nodeList.Add(node);

                SelectChildNodes(node, nodeList);

                this.treeList.Selection.Set(nodeList);
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 자식 노드 선택하기 - SelectChildNodes(parentNode, selectedNodeList)

        /// <summary>
        /// 자식 노드 선택하기
        /// </summary>
        /// <param name="parentNode">부모 노드</param>
        /// <param name="selectedNodeList">선택 노드 리스트</param>
        private void SelectChildNodes(TreeListNode parentNode, List<TreeListNode> selectedNodeList)
        {
            IEnumerator enumerator = parentNode.Nodes.GetEnumerator();

            TreeListNode childNode;

            while(enumerator.MoveNext())
            {
                childNode = (TreeListNode)enumerator.Current;

                selectedNodeList.Add(childNode);

                if(childNode.HasChildren)
                {
                    SelectChildNodes(childNode, selectedNodeList);
                }
            }
        }

        #endregion
    }
}